abacusai.hume_voice — AbacusAI documentation

# abacusai.hume_voice

## Classes

`HumeVoice` | Hume Voice

## Module Contents

class abacusai.hume_voice.HumeVoice(client, name=None, gender=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Hume Voice

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the voice.

    - gender (str) – The gender of the voice.

  name = None
  gender = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict